==> kara-uc-1.1.93.tgz: package/src/kara-uc/components/UCInfo/index.js <==
import React, { Component } from 'react'
import { inject, observer } from 'mobx-react'
import css from './index.scss'
import { PlainMessage, Tost } from 'karaui'
import NickName from './nickName'
import Intro from './intro'
import HeadIcon from './headIcon'
import _ from 'lodash'
import LowerListModal from './telModal/lowerListModal'
import UserInfoModal from './telModal/userInfoModal'

@inject('UCInfoStore', 'ConfigStore')
@observer
class UCInfo extends Component {
  constructor (props) {
    super(props)
    this.state = {
      accountId: '',//当前查看的用户的accountId
      lowerModal: false,//下属列表框是否显示
      pageNo: 1,//下属页码
      pageSize: 10,//每页数量
      lowerList: [],//下属列表
      infoModal: false,//名片信息弹出框是否显示
      accountIdArr: [],//都是查看了谁的名片，压栈方式存accountId，关闭弹框时，remove掉本地存储，并且将此数组赋空
      personData: {},//名片信息
    }
  }

  //展示下属列表的盒子
  showLowerModal = (accountId) => {
    this.setState({
      lowerModal: true,
      accountId
    })
    this.getLowerPerson(accountId, 10)
  }

  //隐藏下属列表盒子
  hideLowerModal = () => {
    this.setState({
      lowerModal: false,
      lowerList: [],
      pageNo: 1
    })
  }

  //滚动加载，更改页码
  getMoreLower = (accountId = this.state.accountId, pageSize = this.state.pageSize) => {
    const {pageNo, pageCount} = this.state
    //当前请求页小于总页数发出请求
    if (pageNo < pageCount) {
      let newPageNo = pageNo + 1

      this.setState({
        pageNo: newPageNo
      }, () => {
        this.getLowerPerson(accountId, pageSize, this.state.pageNo)
      })
    }
  }

  //获取下属列表
  getLowerPerson = (accountId, pageSize = this.state.pageSize, pageNo = 1) => {
    if (pageNo === 1) {
      this.setState({
        pageNo: 1
      })
    }
    const {httpAgent} = this.props
    // const {pageNo} = this.state
    const body = {
      accountId,
      pageInfo: {
        pageNo: pageNo,
        pageSize: pageSize,
      },
    }
    this.props.ConfigStore.config.httpAgent.post(`/search/addressbook/subordinateStaff`, body).then(res => {
      if (res && res.resultCode === '000000') {
        this.setState({
          lowerList: pageNo === 1 ? res.pageInfo.result : _.concat(this.state.lowerList, res.pageInfo.result),
          pageCount: res.pageInfo.pageCount
        })
      }
    })
  }

  //展示详细名片
  showDetailInfoModal = (accountId) => {
    this.hideLowerModal()
    this.setState({
      infoModal: true,
      lowerList: [],
      pageNo: 1
    })
    this.getDetailInfo(accountId)
  }

  //隐藏详细名片弹窗
  hideDetailInfoModal = () => {
    this.setState({
      infoModal: false,
      accountIdArr: [],
      lowerList: [],
    })
  }

  //获取详细名片的信息
  getDetailInfo = (accountId) => {
    const {httpAgent} = this.props

    this.props.ConfigStore.config.httpAgent.get(`/sdm/addressbook/member/${accountId}`).then(res => {
      // console.log('名片信息', res)
      if (res && res.resultCode === '000000' && res.addressBookStaff) {
        this.setState({
          personData: res.addressBookStaff
        })
      } else {
        Tost({type: 'error', msg: '获取用户信息失败', time: 4})
      }
    })

    //  向数组中存入accountID，用来返回上一个，存在本地存储中
    let accArr = _.clone(this.state.accountIdArr)
    accArr.push(accountId)

    // console.log('已经打开的人', accArr)
    this.setState({
      accountIdArr: accArr
    })
  }

  //点击返回按钮，删除accountIdArr的最后一个
  delPopPerson = () => {
    let accArr = _.clone(this.state.accountIdArr)
    //删除数组中的最后一个，
    accArr.pop()
    //  并且显示删除后，数组中最后一个人的详情
    this.getDetailInfo(accArr[accArr.length - 1])
    this.setState({
      accountIdArr: accArr,
    })
  }

  //关注联系人，更改对应状态
  changeStatus = (status) => {
    let newData = _.clone(this.state.personData)
    newData.contactStatus = status
    this.setState({
      personData: newData
    })

  }

  componentDidMount () {
    this.props.ConfigStore.config.httpAgent.get('/account/getCurrentAccountCard').then(
      res => {
        if (res && res.resultCode && res.resultCode === '000000') {
          console.log('个人信息', res)
          this.props.UCInfoStore.getUserCard(res)
        }
        else {
          Tost({type: 'error', msg: '获取用户信息失败', time: 4})
        }
      }
    )
  }

  fomateDate = (strDate, type) => {
    if (!strDate) {
      if (type === 0) {
        return ' 月 日'
      }
      else {
        return '年 月 日'
      }
    }

    let dateStr = strDate.replace(/00:00:00/, '')
    let dateArr = dateStr.split('-')

    // let da = new Date(strDate.replace(/00:00:00/, ""));
    // let year = da.getFullYear() + '年'
    // let month = (da.getMonth() + 1 < 10 ? '0' + (da.getMonth() + 1) : da.getMonth() + 1) + '月'
    // let date = (da.getDate() < 10 ? '0' + (da.getDate()) : da.getDate()) + '日' let year = da.getFullYear() + '年'
    let year = dateArr[0] + '年'
    let month = dateArr[1] + '月'
    let date = dateArr[2] + '日'
    if (type === 0) {
      return [month, date].join('')
    }
    else {
      return [year, month, date].join('')
    }
  }

  render () {
    const {UCInfoStore, ConfigStore, lang} = this.props
    const {karaui} = ConfigStore.config
    const {Scroll} = karaui
    if (ConfigStore === undefined || UCInfoStore === undefined) {
      return null
    }
    const {httpAgent} = ConfigStore.config
    const {updateNickName, updateSign} = UCInfoStore
    let user = ConfigStore.config.user

    const {
      accountId, accountName, bgId, birthDay, companyName, costCenterName, emailAddress, headIcon,
      hireDay, hireDayCount, mobile = '无', nickName, ntAccount, office = '无', organizationName = '无', organizationNameEn = '无', parentAccountName, sameBirthDayCount, sbuName,
      signature, staffCode, tags, workingLocation, parentAccountId, childAccountCount
    } = UCInfoStore.userCard

    console.log('4', UCInfoStore.userCard)
    if (!UCInfoStore.userCard) {
      return null
    }
    const {lowerList, lowerModal, infoModal, personData, accountIdArr} = this.state
    const {
      showDetailInfoModal, getMoreLower, hideDetailInfoModal, getLowerPerson,
      showLowerModal, hideLowerModal, getDetailInfo, delPopPerson, onChat, changeStatus
    } = this
    return (
      <div className={css.UCInfo}>
        <Scroll>
          <HeadIcon headIcon={headIcon} user={user} lang={lang} httpAgent={httpAgent}
                    UCInfoStore={UCInfoStore}/>
          <div className={css.nickName}>
            <NickName lang={lang} nickName={nickName} httpAgent={httpAgent}
                      updateNickName={updateNickName}/>
            <Intro lang={lang} signature={signature} httpAgent={httpAgent}
                   updateSign={updateSign}/>
          </div>
          <div className={`clearfix ${css.workInfo}`}>
            <div><span className='s-hint'>NT</span><span>{ntAccount}</span></div>
            <div><span className={`s-hint`}>{lang.workStation}</span><span>{workingLocation}</span>
            </div>
            <div><span className='s-hint'>{lang.phone}/{lang.tel}</span><span>{mobile}/{office}</span></div>
            <div><span className='s-hint'>{lang.department}</span>
              <span title={organizationName}>{organizationName}</span></div>
            <div><span className='s-hint'>{lang.departmenten}</span>
              <span title={organizationNameEn}>{organizationNameEn}</span></div>

            <div><span className='s-hint'>BU</span><span>{sbuName}</span></div>
            <div><span className={`s-hint`}>CC</span><span>{costCenterName}</span></div>
            <div><span className='s-hint'>{lang.company}</span><span>{companyName}</span></div>


            <div><span className={`s-hint`}>{lang.email}</span>
              <span><a title={emailAddress} className={css.blueText} href={`mailto:${emailAddress}`}>{emailAddress}</a></span>
            </div>


            {/*<div><span className={`s-hint`}>BG</span><span>{bgId}</span></div>*/}

            <div>
              <span className='s-hint'>{lang.superior}</span>
              <span className={`${css.blueText} s-hint`}
                    onClick={() => {this.showDetailInfoModal(parentAccountId)}}>{parentAccountName}</span>
            </div>
            <div>
              <span className='s-hint'>{lang.lower}</span>
              <span
                className={`${childAccountCount === 0 ? '' : css.blueText}  s-hint ${css.lowerDiv}`}
                onMouseEnter={() => {
                  (childAccountCount !== 0 ? this.showLowerModal(accountId) : null)

                }} onMouseLeave={() => {this.hideLowerModal()}}
              >{childAccountCount === 0 ? '暂无' : `${childAccountCount}人`}
                {/*下属列表框*/}
                {lowerModal ? <LowerListModal data={lowerList} showDetailInfoModal={showDetailInfoModal}
                                              getMoreLower={getMoreLower}/> : null}
              </span>

            </div>

            <div>
              <span className='s-hint'>{lang.label}</span><span title={tags}>{tags}</span>
            </div>
          </div>
          <div className={css.brithday}>
            <div><span
              className='s-hint'>{lang.birthday}</span><span>{this.fomateDate(birthDay, 0)}</span><span>共{sameBirthDayCount}名同学与您同一天生日</span>
            </div>
            <div><span
              className='s-hint'>{lang.entryDate}</span><span>{this.fomateDate(hireDay, 1)}</span><span>您加入亚信大家庭已经{hireDayCount}天了，感谢您的辛苦付出</span>
            </div>
          </div>
        </Scroll>

        <UserInfoModal show={infoModal} data={personData} close={hideDetailInfoModal} getDetailInfo={getDetailInfo}
                       showDetailInfoModal={showDetailInfoModal} accountIdArr={accountIdArr}
                       delPopPerson={delPopPerson} onChat={onChat} httpAgent={httpAgent} changeStatus={changeStatus}
                       getLowerPerson={getLowerPerson} lowerData={lowerList} getMore={getMoreLower}
        />

      </div>
    )
  }
}

export default UCInfo

==> kara-uc-1.1.99.tgz: package/src/kara-uc/components/UCInfo/index.js <==
import React, { Component } from 'react'
import { inject, observer } from 'mobx-react'
import css from './index.scss'
import { PlainMessage, Tost } from 'karaui'
import NickName from './nickName'
import Intro from './intro'
import HeadIcon from './headIcon'
import _ from 'lodash'
import LowerListModal from './telModal/lowerListModal'
import UserInfoModal from './telModal/userInfoModal'

@inject('UCInfoStore', 'ConfigStore')
@observer
class UCInfo extends Component {
  constructor (props) {
    super(props)
    this.state = {
      accountId: '',//当前查看的用户的accountId
      lowerModal: false,//下属列表框是否显示
      pageNo: 1,//下属页码
      pageSize: 10,//每页数量
      lowerList: [],//下属列表
      infoModal: false,//名片信息弹出框是否显示
      accountIdArr: [],//都是查看了谁的名片，压栈方式存accountId，关闭弹框时，remove掉本地存储，并且将此数组赋空
      personData: {},//名片信息
    }
  }

  //展示下属列表的盒子
  showLowerModal = (accountId) => {
    this.setState({
      lowerModal: true,
      accountId
    })
    this.getLowerPerson(accountId, 10)
  }

  //隐藏下属列表盒子
  hideLowerModal = () => {
    this.setState({
      lowerModal: false,
      lowerList: [],
      pageNo: 1
    })
  }

  //滚动加载，更改页码
  getMoreLower = (accountId = this.state.accountId, pageSize = this.state.pageSize) => {
    const {pageNo, pageCount} = this.state
    //当前请求页小于总页数发出请求
    if (pageNo < pageCount) {
      let newPageNo = pageNo + 1

      this.setState({
        pageNo: newPageNo
      }, () => {
        this.getLowerPerson(accountId, pageSize, this.state.pageNo)
      })
    }
  }

  //获取下属列表
  getLowerPerson = (accountId, pageSize = this.state.pageSize, pageNo = 1) => {
    if (pageNo === 1) {
      this.setState({
        pageNo: 1
      })
    }
    const {httpAgent} = this.props
    // const {pageNo} = this.state
    const body = {
      accountId,
      pageInfo: {
        pageNo: pageNo,
        pageSize: pageSize,
      },
    }
    this.props.ConfigStore.config.httpAgent.post(`/search/addressbook/subordinateStaff`, body).then(res => {
      if (res && res.resultCode === '000000') {
        this.setState({
          lowerList: pageNo === 1 ? res.pageInfo.result : _.concat(this.state.lowerList, res.pageInfo.result),
          pageCount: res.pageInfo.pageCount
        })
      }
    })
  }

  //展示详细名片
  showDetailInfoModal = (accountId) => {
    this.hideLowerModal()
    this.setState({
      infoModal: true,
      lowerList: [],
      pageNo: 1
    })
    this.getDetailInfo(accountId)
  }

  //隐藏详细名片弹窗
  hideDetailInfoModal = () => {
    this.setState({
      infoModal: false,
      accountIdArr: [],
      lowerList: [],
    })
  }

  //获取详细名片的信息
  getDetailInfo = (accountId) => {
    const {httpAgent} = this.props

    this.props.ConfigStore.config.httpAgent.get(`/sdm/addressbook/member/${accountId}`).then(res => {
      // console.log('名片信息', res)
      if (res && res.resultCode === '000000' && res.addressBookStaff) {
        this.setState({
          personData: res.addressBookStaff
        })
      } else {
        Tost({type: 'error', msg: '获取用户信息失败', time: 4})
      }
    })

    //  向数组中存入accountID，用来返回上一个，存在本地存储中
    let accArr = _.clone(this.state.accountIdArr)
    accArr.push(accountId)

    // console.log('已经打开的人', accArr)
    this.setState({
      accountIdArr: accArr
    })
  }

  //点击返回按钮，删除accountIdArr的最后一个
  delPopPerson = () => {
    let accArr = _.clone(this.state.accountIdArr)
    //删除数组中的最后一个，
    accArr.pop()
    //  并且显示删除后，数组中最后一个人的详情
    this.getDetailInfo(accArr[accArr.length - 1])
    this.setState({
      accountIdArr: accArr,
    })
  }

  //关注联系人，更改对应状态
  changeStatus = (status) => {
    let newData = _.clone(this.state.personData)
    newData.contactStatus = status
    this.setState({
      personData: newData
    })

  }

  componentDidMount () {
    this.props.ConfigStore.config.httpAgent.get('/account/getCurrentAccountCard').then(
      res => {
        if (res && res.resultCode && res.resultCode === '000000') {
          // console.log('个人信息', res)
          this.props.UCInfoStore.getUserCard(res)
        }
        else {
          Tost({type: 'error', msg: '获取用户信息失败', time: 4})
        }
      }
    )
  }

  fomateDate = (strDate, type) => {
    if (!strDate) {
      if (type === 0) {
        return ' 月 日'
      }
      else {
        return '年 月 日'
      }
    }

    let dateStr = strDate.replace(/00:00:00/, '')
    let dateArr = dateStr.split('-')

    // let da = new Date(strDate.replace(/00:00:00/, ""));
    // let year = da.getFullYear() + '年'
    // let month = (da.getMonth() + 1 < 10 ? '0' + (da.getMonth() + 1) : da.getMonth() + 1) + '月'
    // let date = (da.getDate() < 10 ? '0' + (da.getDate()) : da.getDate()) + '日' let year = da.getFullYear() + '年'
    let year = dateArr[0] + '年'
    let month = dateArr[1] + '月'
    let date = dateArr[2] + '日'
    if (type === 0) {
      return [month, date].join('')
    }
    else {
      return [year, month, date].join('')
    }
  }

  render () {
    const {UCInfoStore, ConfigStore, lang} = this.props
    const {karaui} = ConfigStore.config
    const {Scroll} = karaui
    if (ConfigStore === undefined || UCInfoStore === undefined) {
      return null
    }
    const {httpAgent} = ConfigStore.config
    const {updateNickName, updateSign} = UCInfoStore
    let user = ConfigStore.config.user

    const {
      accountId, accountName, bgId, birthDay, companyName, costCenterName, emailAddress, headIcon,
      hireDay, hireDayCount, mobile = '无', nickName, ntAccount, office = '无', organizationName = '无', organizationNameEn = '无', parentAccountName = '无', sameBirthDayCount, sbuName,
      signature, staffCode, tags, workingLocation, parentAccountId = '无', childAccountCount = 0
    } = UCInfoStore.userCard

    // console.log('4', UCInfoStore.userCard)
    if (!UCInfoStore.userCard) {
      return null
    }
    const {lowerList, lowerModal, infoModal, personData, accountIdArr} = this.state
    const {
      showDetailInfoModal, getMoreLower, hideDetailInfoModal, getLowerPerson,
      showLowerModal, hideLowerModal, getDetailInfo, delPopPerson, onChat, changeStatus
    } = this
    return (
      <div className={css.UCInfo}>
        <Scroll>
          <HeadIcon headIcon={headIcon} user={user} lang={lang} httpAgent={httpAgent}
                    UCInfoStore={UCInfoStore}/>
          <div className={css.nickName}>
            <NickName lang={lang} nickName={nickName} httpAgent={httpAgent}
                      updateNickName={updateNickName}/>
            <Intro lang={lang} signature={signature} httpAgent={httpAgent}
                   updateSign={updateSign}/>
          </div>
          <div className={`clearfix ${css.workInfo}`}>
            <div><span className='s-hint'>NT</span><span>{ntAccount}</span></div>
            <div><span className={`s-hint`}>{lang.workStation}</span><span>{workingLocation}</span>
            </div>
            <div><span className='s-hint'>{lang.phone}/{lang.tel}</span><span>{mobile}/{office}</span></div>
            <div><span className='s-hint'>{lang.department}</span>
              <span title={organizationName}>{organizationName}</span></div>
            <div><span className='s-hint'>{lang.departmenten}</span>
              <span title={organizationNameEn}>{organizationNameEn}</span></div>

            <div><span className='s-hint'>BU</span><span>{sbuName}</span></div>
            <div><span className={`s-hint`}>CC</span><span>{costCenterName}</span></div>
            <div><span className='s-hint'>{lang.company}</span><span>{companyName}</span></div>


            <div><span className={`s-hint`}>{lang.email}</span>
              <span><a title={emailAddress} className={css.blueText} href={`mailto:${emailAddress}`}>{emailAddress}</a></span>
            </div>


            {/*<div><span className={`s-hint`}>BG</span><span>{bgId}</span></div>*/}

            <div>
              <span className='s-hint'>{lang.superior}</span>
              {parentAccountId !== '无' && parentAccountName !== '无' ?
                <span className={`${css.blueText} s-hint`}
                      onClick={() => {this.showDetailInfoModal(parentAccountId)}}>{parentAccountName}</span> :
                <span>{parentAccountName}</span>
              }

            </div>
            <div>
              <span className='s-hint'>{lang.lower}</span>
              <span
                className={`${childAccountCount === 0 ? '' : css.blueText}  s-hint ${css.lowerDiv}`}
                onMouseEnter={() => {
                  (childAccountCount !== 0 ? this.showLowerModal(accountId) : null)

                }} onMouseLeave={() => {this.hideLowerModal()}}
              >{childAccountCount === 0 ? '暂无' : `${childAccountCount}人`}
                {/*下属列表框*/}
                {lowerModal ? <LowerListModal data={lowerList} showDetailInfoModal={showDetailInfoModal}
                                              getMoreLower={getMoreLower}/> : null}
              </span>

            </div>

            <div>
              <span className='s-hint'>{lang.label}</span><span title={tags}>{tags}</span>
            </div>
          </div>
          <div className={css.brithday}>
            <div><span
              className='s-hint'>{lang.birthday}</span><span>{this.fomateDate(birthDay, 0)}</span><span>共{sameBirthDayCount}名同学与您同一天生日</span>
            </div>
            <div><span
              className='s-hint'>{lang.entryDate}</span><span>{this.fomateDate(hireDay, 1)}</span><span>您加入亚信大家庭已经{hireDayCount}天了，感谢您的辛苦付出</span>
            </div>
          </div>
        </Scroll>

        <UserInfoModal show={infoModal} data={personData} close={hideDetailInfoModal} getDetailInfo={getDetailInfo}
                       showDetailInfoModal={showDetailInfoModal} accountIdArr={accountIdArr}
                       delPopPerson={delPopPerson} onChat={onChat} httpAgent={httpAgent} changeStatus={changeStatus}
                       getLowerPerson={getLowerPerson} lowerData={lowerList} getMore={getMoreLower}
        />

      </div>
    )
  }
}

export default UCInfo
